@@ -6,12 +6,8 @@ from fontTools.misc.loggingTools import LogMixin
 import collections
 import os
 import posixpath
-import plistlib
-
-try:
-    import xml.etree.cElementTree as ET
-except ImportError:
-    import xml.etree.ElementTree as ET
+from fontTools.misc import etree as ET
+from fontTools.misc import plistlib
 
 """
     designSpaceDocument
@@ -31,30 +27,6 @@ XML_NS = "{http://www.w3.org/XML/1998/namespace}"
 XML_LANG = XML_NS + "lang"
 
 
-def to_plist(value):
-    try:
-        # Python 2
-        string = plistlib.writePlistToString(value)
-    except AttributeError:
-        # Python 3
-        string = plistlib.dumps(value).decode()
-    return ET.fromstring(string)[0]
-
-
-def from_plist(element):
-    if element is None:
-        return {}
-    plist = ET.Element('plist')
-    plist.append(element)
-    string = ET.tostring(plist)
-    try:
-        # Python 2
-        return plistlib.readPlistFromString(string)
-    except AttributeError:
-        # Python 3
-        return plistlib.loads(string, fmt=plistlib.FMT_XML)
-
-
 def posix(path):
     """Normalize paths using forward slash to work also on Windows."""
     new_path = posixpath.join(*path.split(os.path.sep))
@@ -88,23 +60,6 @@ class DesignSpaceDocumentError(Exception):
             ": %r" % self.obj if self.obj is not None else "")
 
 
-def _indent(elem, whitespace="    ", level=0):
-    # taken from http://effbot.org/zone/element-lib.htm#prettyprint
-    i = "\n" + level * whitespace
-    if len(elem):
-        if not elem.text or not elem.text.strip():
-            elem.text = i + whitespace
-        if not elem.tail or not elem.tail.strip():
-            elem.tail = i
-        for elem in elem:
-            _indent(elem, whitespace, level+1)
-        if not elem.tail or not elem.tail.strip():
-            elem.tail = i
-    else:
-        if level and (not elem.tail or not elem.tail.strip()):
-            elem.tail = i
-
-
 class AsDictMixin(object):
 
     def asdict(self):
@@ -280,7 +235,6 @@ class InstanceDescriptor(SimpleDescriptor):
         self.localisedStyleMapStyleName = {}
         self.localisedStyleMapFamilyName = {}
         self.glyphs = {}
-        self.mutedGlyphNames = []
         self.kerning = True
         self.info = True
 
@@ -291,25 +245,25 @@ class InstanceDescriptor(SimpleDescriptor):
     filename = posixpath_property("_filename")
 
     def setStyleName(self, styleName, languageCode="en"):
-        self.localisedStyleName[languageCode] = styleName
+        self.localisedStyleName[languageCode] = tounicode(styleName)
 
     def getStyleName(self, languageCode="en"):
         return self.localisedStyleName.get(languageCode)
 
     def setFamilyName(self, familyName, languageCode="en"):
-        self.localisedFamilyName[languageCode] = familyName
+        self.localisedFamilyName[languageCode] = tounicode(familyName)
 
     def getFamilyName(self, languageCode="en"):
         return self.localisedFamilyName.get(languageCode)
 
     def setStyleMapStyleName(self, styleMapStyleName, languageCode="en"):
-        self.localisedStyleMapStyleName[languageCode] = styleMapStyleName
+        self.localisedStyleMapStyleName[languageCode] = tounicode(styleMapStyleName)
 
     def getStyleMapStyleName(self, languageCode="en"):
         return self.localisedStyleMapStyleName.get(languageCode)
 
     def setStyleMapFamilyName(self, styleMapFamilyName, languageCode="en"):
-        self.localisedStyleMapFamilyName[languageCode] = styleMapFamilyName
+        self.localisedStyleMapFamilyName[languageCode] = tounicode(styleMapFamilyName)
 
     def getStyleMapFamilyName(self, languageCode="en"):
         return self.localisedStyleMapFamilyName.get(languageCode)
@@ -410,7 +364,7 @@ class BaseDocWriter(object):
         self._axes = []     # for use by the writer only
         self._rules = []    # for use by the writer only
 
-    def write(self, pretty=True, encoding="utf-8", xml_declaration=True):
+    def write(self, pretty=True, encoding="UTF-8", xml_declaration=True):
         if self.documentObject.axes:
             self.root.append(ET.Element("axes"))
         for axisObject in self.documentObject.axes:
@@ -434,14 +388,13 @@ class BaseDocWriter(object):
         if self.documentObject.lib:
             self._addLib(self.documentObject.lib)
 
-        if pretty:
-            _indent(self.root, whitespace=self._whiteSpace)
         tree = ET.ElementTree(self.root)
         tree.write(
             self.path,
             encoding=encoding,
             method='xml',
             xml_declaration=xml_declaration,
+            pretty_print=pretty,
         )
 
     def _makeLocationElement(self, locationObject, name=None):
@@ -511,7 +464,7 @@ class BaseDocWriter(object):
             axisElement.attrib['hidden'] = "1"
         for languageCode, labelName in sorted(axisObject.labelNames.items()):
             languageElement = ET.Element('labelname')
-            languageElement.attrib[u'xml:lang'] = languageCode
+            languageElement.attrib[XML_LANG] = languageCode
             languageElement.text = labelName
             axisElement.append(languageElement)
         if axisObject.map:
@@ -538,7 +491,7 @@ class BaseDocWriter(object):
                 if code == "en":
                     continue  # already stored in the element attribute
                 localisedStyleNameElement = ET.Element('stylename')
-                localisedStyleNameElement.attrib["xml:lang"] = code
+                localisedStyleNameElement.attrib[XML_LANG] = code
                 localisedStyleNameElement.text = instanceObject.getStyleName(code)
                 instanceElement.append(localisedStyleNameElement)
         if instanceObject.localisedFamilyName:
@@ -548,7 +501,7 @@ class BaseDocWriter(object):
                 if code == "en":
                     continue  # already stored in the element attribute
                 localisedFamilyNameElement = ET.Element('familyname')
-                localisedFamilyNameElement.attrib["xml:lang"] = code
+                localisedFamilyNameElement.attrib[XML_LANG] = code
                 localisedFamilyNameElement.text = instanceObject.getFamilyName(code)
                 instanceElement.append(localisedFamilyNameElement)
         if instanceObject.localisedStyleMapStyleName:
@@ -558,7 +511,7 @@ class BaseDocWriter(object):
                 if code == "en":
                     continue
                 localisedStyleMapStyleNameElement = ET.Element('stylemapstylename')
-                localisedStyleMapStyleNameElement.attrib["xml:lang"] = code
+                localisedStyleMapStyleNameElement.attrib[XML_LANG] = code
                 localisedStyleMapStyleNameElement.text = instanceObject.getStyleMapStyleName(code)
                 instanceElement.append(localisedStyleMapStyleNameElement)
         if instanceObject.localisedStyleMapFamilyName:
@@ -568,7 +521,7 @@ class BaseDocWriter(object):
                 if code == "en":
                     continue
                 localisedStyleMapFamilyNameElement = ET.Element('stylemapfamilyname')
-                localisedStyleMapFamilyNameElement.attrib["xml:lang"] = code
+                localisedStyleMapFamilyNameElement.attrib[XML_LANG] = code
                 localisedStyleMapFamilyNameElement.text = instanceObject.getStyleMapFamilyName(code)
                 instanceElement.append(localisedStyleMapFamilyNameElement)
 
@@ -599,7 +552,7 @@ class BaseDocWriter(object):
             instanceElement.append(infoElement)
         if instanceObject.lib:
             libElement = ET.Element('lib')
-            libElement.append(to_plist(instanceObject.lib))
+            libElement.append(plistlib.totree(instanceObject.lib, indent_level=4))
             instanceElement.append(libElement)
         self.root.findall('.instances')[0].append(instanceElement)
 
@@ -652,7 +605,7 @@ class BaseDocWriter(object):
 
     def _addLib(self, dict):
         libElement = ET.Element('lib')
-        libElement.append(to_plist(dict))
+        libElement.append(plistlib.totree(dict, indent_level=2))
         self.root.append(libElement)
 
     def _writeGlyphElement(self, instanceElement, instanceObject, glyphName, data):
@@ -719,12 +672,6 @@ class BaseDocReader(LogMixin):
         self.readInstances()
         self.readLib()
 
-    def getSourcePaths(self, makeGlyphs=True, makeKerning=True, makeInfo=True):
-        paths = []
-        for name in self.documentObject.sources.keys():
-            paths.append(self.documentObject.sources[name][0].path)
-        return paths
-
     def readRules(self):
         # we also need to read any conditions that are outside of a condition set.
         rules = []
@@ -801,12 +748,11 @@ class BaseDocReader(LogMixin):
                 b = float(mapElement.attrib['output'])
                 axisObject.map.append((a, b))
             for labelNameElement in axisElement.findall('labelname'):
-                # Note: elementtree reads the xml:lang attribute name as
+                # Note: elementtree reads the "xml:lang" attribute name as
                 # '{http://www.w3.org/XML/1998/namespace}lang'
                 for key, lang in labelNameElement.items():
                     if key == XML_LANG:
-                        labelName = labelNameElement.text
-                        axisObject.labelNames[lang] = labelName
+                        axisObject.labelNames[lang] = tounicode(labelNameElement.text)
             self.documentObject.axes.append(axisObject)
             self.axisDefaults[axisObject.name] = axisObject.default
         self.documentObject.defaultLoc = self.axisDefaults
@@ -963,7 +909,7 @@ class BaseDocReader(LogMixin):
 
     def readLibElement(self, libElement, instanceObject):
         """Read the lib element for the given instance."""
-        instanceObject.lib = from_plist(libElement[0])
+        instanceObject.lib = plistlib.fromtree(libElement[0])
 
     def readInfoElement(self, infoElement, instanceObject):
         """ Read the info element."""
@@ -1030,7 +976,7 @@ class BaseDocReader(LogMixin):
     def readLib(self):
         """Read the lib element for the whole document."""
         for libElement in self.root.findall(".lib"):
-            self.documentObject.lib = from_plist(libElement[0])
+            self.documentObject.lib = plistlib.fromtree(libElement[0])
 
 
 class DesignSpaceDocument(LogMixin, AsDictMixin):
@@ -1090,7 +1036,7 @@ class DesignSpaceDocument(LogMixin, AsDictMixin):
             xml_declaration = False
         elif encoding is None or encoding == "utf-8":
             f = BytesIO()
-            encoding = "utf-8"
+            encoding = "UTF-8"
             xml_declaration = True
         else:
             raise ValueError("unsupported encoding: '%s'" % encoding)
@@ -1099,6 +1045,8 @@ class DesignSpaceDocument(LogMixin, AsDictMixin):
         return f.getvalue()
 
     def read(self, path):
+        if hasattr(path, "__fspath__"):  # support os.PathLike objects
+            path = path.__fspath__()
         self.path = path
         self.filename = os.path.basename(path)
         reader = self.readerClass(path, self)
@@ -1107,6 +1055,8 @@ class DesignSpaceDocument(LogMixin, AsDictMixin):
             self.findDefault()
 
     def write(self, path):
+        if hasattr(path, "__fspath__"):  # support os.PathLike objects
+            path = path.__fspath__()
         self.path = path
         self.filename = os.path.basename(path)
         self.updatePaths()
@@ -1159,21 +1109,11 @@ class DesignSpaceDocument(LogMixin, AsDictMixin):
 
 
         """
+        assert self.path is not None
         for descriptor in self.sources + self.instances:
-            # check what the relative path really should be?
-            expectedFilename = None
-            if descriptor.path is not None and self.path is not None:
-                expectedFilename = self._posixRelativePath(descriptor.path)
-
-            # 3
-            if descriptor.filename is None and descriptor.path is not None and self.path is not None:
+            if descriptor.path is not None:
+                # case 3 and 4: filename gets updated and relativized
                 descriptor.filename = self._posixRelativePath(descriptor.path)
-                continue
-
-            # 4
-            if descriptor.filename is not None and descriptor.path is not None and self.path is not None:
-                if descriptor.filename is not expectedFilename:
-                    descriptor.filename = expectedFilename
 
     def addSource(self, sourceDescriptor):
         self.sources.append(sourceDescriptor)
@@ -1188,11 +1128,14 @@ class DesignSpaceDocument(LogMixin, AsDictMixin):
         self.rules.append(ruleDescriptor)
 
     def newDefaultLocation(self):
+        """Return default location in design space."""
         # Without OrderedDict, output XML would be non-deterministic.
         # https://github.com/LettError/designSpaceDocument/issues/10
         loc = collections.OrderedDict()
         for axisDescriptor in self.axes:
-            loc[axisDescriptor.name] = axisDescriptor.default
+            loc[axisDescriptor.name] = axisDescriptor.map_forward(
+                axisDescriptor.default
+            )
         return loc
 
     def updateFilenameFromPath(self, masters=True, instances=True, force=False):
@@ -1236,43 +1179,43 @@ class DesignSpaceDocument(LogMixin, AsDictMixin):
         return None
 
     def findDefault(self):
-        # new default finder
-        # take the sourcedescriptor with the location at all the defaults
-        # if we can't find it, return None, let someone else figure it out
+        """Set and return SourceDescriptor at the default location or None.
+
+        The default location is the set of all `default` values in user space
+        of all axes.
+        """
         self.default = None
+
+        # Convert the default location from user space to design space before comparing
+        # it against the SourceDescriptor locations (always in design space).
+        default_location_design = {
+            axis.name: axis.map_forward(self.defaultLoc[axis.name])
+            for axis in self.axes
+        }
+
         for sourceDescriptor in self.sources:
-            if sourceDescriptor.location == self.defaultLoc:
-                # we choose you!
+            if sourceDescriptor.location == default_location_design:
                 self.default = sourceDescriptor
                 return sourceDescriptor
+
         return None
 
     def normalizeLocation(self, location):
-        # adapted from fontTools.varlib.models.normalizeLocation because:
-        #   - this needs to work with axis names, not tags
-        #   - this needs to accomodate anisotropic locations
-        #   - the axes are stored differently here, it's just math
+        from fontTools.varLib.models import normalizeValue
+
         new = {}
         for axis in self.axes:
             if axis.name not in location:
                 # skipping this dimension it seems
                 continue
-            v = location.get(axis.name, axis.default)
-            if type(v) == tuple:
-                v = v[0]
-            if v == axis.default:
-                v = 0.0
-            elif v < axis.default:
-                if axis.default == axis.minimum:
-                    v = 0.0
-                else:
-                    v = (max(v, axis.minimum) - axis.default) / (axis.default - axis.minimum)
-            else:
-                if axis.default == axis.maximum:
-                    v = 0.0
-                else:
-                    v = (min(v, axis.maximum) - axis.default) / (axis.maximum - axis.default)
-            new[axis.name] = v
+            value = location[axis.name]
+            # 'anisotropic' location, take first coord only
+            if isinstance(value, tuple):
+                value = value[0]
+            triple = [
+                axis.map_forward(v) for v in (axis.minimum, axis.default, axis.maximum)
+            ]
+            new[axis.name] = normalizeValue(value, triple)
         return new
 
     def normalize(self):
